@@ -10,11 +10,6 @@ try:
 except ImportError:
     version = 'unknown'
 
-# Uncomment the following line to treat all DeprecationWarnings as
-# exceptions
-from astropy.tests.helper import enable_deprecations_as_exceptions
-enable_deprecations_as_exceptions()
-
 # Uncomment and customize the following lines to add/remove entries
 # from the list of packages for which version numbers are displayed
 # when running the tests.
