@@ -18,9 +18,10 @@ from astropy.utils.exceptions import (AstropyUserWarning,
                                       AstropyDeprecationWarning)
 
 # LOCAL
-from . import binning, exceptions, units, utils
-from .models import Empirical1D
-from .spectrum import BaseSourceSpectrum, SourceSpectrum, SpectralElement
+from synphot import binning, exceptions, units, utils
+from synphot.models import Empirical1D
+from synphot.spectrum import (BaseSourceSpectrum, SourceSpectrum,
+                              SpectralElement)
 
 __all__ = ['Observation']
 
@@ -254,7 +255,7 @@ class Observation(BaseSourceSpectrum):
             If not a Quantity, assumed to be in Angstrom.
             If `None`, `binset` is used.
 
-        flux_unit : str or `~astropy.units.core.Unit` or `None`
+        flux_unit : str or `~astropy.units.Unit` or `None`
             Flux is converted to this unit.
             If not given, internal unit is used.
 
@@ -426,7 +427,7 @@ class Observation(BaseSourceSpectrum):
 
         Parameters
         ----------
-        flux_unit : str or `~astropy.units.core.Unit` or `None`
+        flux_unit : str or `~astropy.units.Unit` or `None`
             The unit of effective stimulus.
             COUNT gives result in count/s (see :meth:`countrate` for more
             options).
@@ -458,7 +459,7 @@ class Observation(BaseSourceSpectrum):
         if flux_unit == u.count or flux_unit_name == units.OBMAG.to_string():
             val = self.countrate(area, binned=False, wavelengths=wavelengths)
 
-            if flux_unit.decompose() == u.mag:
+            if flux_unit == units.OBMAG:
                 eff_stim = (-2.5 * np.log10(val.value)) * flux_unit
             else:
                 eff_stim = val
@@ -638,7 +639,7 @@ class Observation(BaseSourceSpectrum):
             If `None`, ``self.waveset`` or `binset` is used, depending
             on ``binned``.
 
-        flux_unit : str or `~astropy.units.core.Unit` or `None`
+        flux_unit : str or `~astropy.units.Unit` or `None`
             Flux is converted to this unit for plotting.
             If not given, internal unit is used.
 
