@@ -14,20 +14,15 @@ import numpy as np
 from astropy import log
 from astropy import units as u
 from astropy.modeling import Model
+from astropy.modeling.core import CompoundModel
 from astropy.modeling.models import RedshiftScaleFactor, Scale
 from astropy.utils.exceptions import AstropyUserWarning
 from astropy.utils import metadata
 
 # LOCAL
-from . import exceptions, specio, units, utils
-from .compat import ASTROPY_LT_4_0
-from .config import Conf, conf
-from .models import ConstFlux1D, Empirical1D, get_waveset, get_metadata
-
-if ASTROPY_LT_4_0:
-    from astropy.modeling.core import _CompoundModel as CompoundModel
-else:
-    from astropy.modeling.core import CompoundModel
+from synphot import exceptions, specio, units, utils
+from synphot.config import Conf, conf
+from synphot.models import ConstFlux1D, Empirical1D, get_waveset, get_metadata
 
 __all__ = ['BaseSpectrum', 'BaseSourceSpectrum', 'SourceSpectrum',
            'BaseUnitlessSpectrum', 'SpectralElement']
@@ -45,7 +40,7 @@ class BaseSpectrum:
     Parameters
     ----------
     modelclass : cls
-        Model class from `astropy.modeling.models`.
+        Model class from `astropy.modeling`.
 
     clean_meta : bool
         Scrub "expr" and "header" entries from input metadata before merging.
@@ -447,7 +442,7 @@ class BaseSpectrum:
             integration is requested but no possible, trapezoid integration
             is done anyway.
 
-        flux_unit : str, `~astropy.units.core.Unit`, or `None`
+        flux_unit : str, `~astropy.units.Unit`, or `None`
             **This option is only available for source spectrum.**
             For trapezoid integration, flux is converted to this unit for
             sampling before integration. For analytical integration, while
@@ -863,7 +858,7 @@ class BaseSpectrum:
             If not a Quantity, assumed to be in Angstrom.
             If `None`, ``self.waveset`` is used.
 
-        flux_unit : str, `~astropy.units.core.Unit`, or `None`
+        flux_unit : str, `~astropy.units.Unit`, or `None`
             This option is not applicable to unitless spectrum like bandpass.
             Flux is converted to this unit before written out.
             If not given, internal unit is used.
@@ -879,7 +874,7 @@ class BaseSpectrum:
             ``specutils`` is not installed.
 
         """
-        from .compat import HAS_SPECUTILS
+        from synphot.compat import HAS_SPECUTILS
 
         if not HAS_SPECUTILS:  # pragma: no cover
             raise ImportError('specutils must be installed to use this method')
@@ -928,7 +923,7 @@ class BaseSourceSpectrum(BaseSpectrum):
             Wavelength values for sampling. If not a Quantity,
             assumed to be in Angstrom.
 
-        flux_unit : str, `~astropy.units.core.Unit`, or `None`
+        flux_unit : str, `~astropy.units.Unit`, or `None`
             Flux is converted to this unit.
             If not given, internal unit is used.
 
@@ -1271,7 +1266,7 @@ class SourceSpectrum(BaseSourceSpectrum):
             If not a Quantity, assumed to be in Angstrom.
             If `None`, ``self.waveset`` is used.
 
-        flux_unit : str, `~astropy.units.core.Unit`, or `None`
+        flux_unit : str, `~astropy.units.Unit`, or `None`
             Flux is converted to this unit for plotting.
             If not given, internal unit is used.
 
@@ -1305,7 +1300,7 @@ class SourceSpectrum(BaseSourceSpectrum):
             If not a Quantity, assumed to be in Angstrom.
             If `None`, ``self.waveset`` is used.
 
-        flux_unit : str, `~astropy.units.core.Unit`, or `None`
+        flux_unit : str, `~astropy.units.Unit`, or `None`
             Flux is converted to this unit before written out.
             If not given, internal unit is used.
 
@@ -1485,7 +1480,7 @@ class SpectralElement(BaseUnitlessSpectrum):
         wavelengths : array-like, `~astropy.units.quantity.Quantity`, or `None`
             Wavelength values for integration.
             If not a Quantity, assumed to be in Angstrom.
-            If `None`, `waveset` is used.
+            If `None`, ``waveset`` is used.
 
         threshold : float
             If less than this fraction of flux or throughput falls
@@ -1799,7 +1794,7 @@ class SpectralElement(BaseUnitlessSpectrum):
         Parameters
         ----------
         kwargs : dict
-            See :meth:`integrate`.
+            See :meth:`~synphot.spectrum.BaseSpectrum.integrate`.
 
         Returns
         -------
